==> RIdeogram_0.2.1.tar.gz: RIdeogram/README.md <==
# RIdeogram: Drawing SVG Graphics to Visualize and Map Genome-Wide Data on Idiograms

`RIdeogram` is a R package to draw SVG graphics to visualize and map genome-wide data on idiograms (Scalable Vector Graphics http://tutorials.jenkov.com/svg/index.html). 

![image](https://github.com/TickingClock1992/RIdeogram/blob/master/vignettes/figures/example4.png)

![image](https://github.com/TickingClock1992/RIdeogram/blob/master/vignettes/figures/example14.png)

![image](https://github.com/TickingClock1992/RIdeogram/blob/master/vignettes/figures/example17.png)

# Installation

To install package from Github, you need to install the `devtools` package first<br>
```
install.packages("devtools")
library(devtools)
```
Then, you can install the package `RIdeogram`<br>
```
devtools::install_github('TickingClock1992/RIdeogram')
```

To install the package `RIdeogram` from CRAN<br>
```
install.packages("RIdeogram")
```

# Citation

Zhaodong Hao, Dekang Lv, Ying Ge, Jisen Shi, Dolf Weijers, Guangchuang Yu, and Jinhui
Chen (2019). RIdeogram: Drawing SVG graphics to visualize and map
genome-wide data on idiograms. R package version 0.2.0.

# Usage

https://cran.r-project.org/web/packages/RIdeogram/vignettes/RIdeogram.html

# Maintainer

Zhaodong Hao <haozd1992@163.com> <br>
Key Laboratory of Forest Genetics and Biotechnology, Ministry of Education of China <br>
College of Forestry, Nanjing Forestry University <br>
Nanjing 210037, China <br>

https://github.com/TickingClock1992

# THANKS
Welcome to any suggestions and discussions.

==> RIdeogram_0.2.2.tar.gz: RIdeogram/README.md <==
# RIdeogram: Drawing SVG Graphics to Visualize and Map Genome-Wide Data on Idiograms

`RIdeogram` is a R package to draw SVG graphics to visualize and map genome-wide data on idiograms (Scalable Vector Graphics http://tutorials.jenkov.com/svg/index.html). 

![image](https://github.com/TickingClock1992/RIdeogram/blob/master/vignettes/figures/example4.png)

![image](https://github.com/TickingClock1992/RIdeogram/blob/master/vignettes/figures/example14.png)

![image](https://github.com/TickingClock1992/RIdeogram/blob/master/vignettes/figures/example17.png)

# Installation

To install package from Github, you need to install the `devtools` package first<br>
```
install.packages("devtools")
library(devtools)
```
Then, you can install the package `RIdeogram`<br>
```
devtools::install_github('TickingClock1992/RIdeogram')
```

To install the package `RIdeogram` from CRAN<br>
```
install.packages("RIdeogram")
```

# Citation

Hao Z, Lv D, Ge Y, Shi J, Weijers D, Yu G, Chen J. 2020. RIdeogram: drawing SVG graphics to visualize and map genome-wide data on the idiograms. PeerJ Comput. Sci. 6:e251 http://doi.org/10.7717/peerj-cs.251

# Usage

https://cran.r-project.org/web/packages/RIdeogram/vignettes/RIdeogram.html

# Maintainer

Zhaodong Hao <haozd1992@163.com> <br>
Key Laboratory of Forest Genetics and Biotechnology, Ministry of Education of China <br>
College of Forestry, Nanjing Forestry University <br>
Nanjing 210037, China <br>

https://github.com/TickingClock1992

# THANKS
Welcome to any suggestions and discussions.
